@@ -8,10 +8,12 @@ class Skill(Model):
     users = models.ManyToManyField(settings.AUTH_USER_MODEL, blank=True, related_name="skills")
 
     class Meta:
-        permission_classes=[]
         serializer_fields=["@id", "name"]
         nested_fields=[]
+        anonymous_perms = ['view']
+        authenticated_perms = ['inherit', 'add', 'change', 'delete']
         container_path = 'skills/'
+        rdf_type = 'hd:skill'
 
 
     def __str__(self):
